==> WWW-Hetzner-0.001.tar.gz: WWW-Hetzner-0.001/lib/WWW/Hetzner/CLI/Cmd/Network/Cmd/Create.pm <==
package WWW::Hetzner::CLI::Cmd::Network::Cmd::Create;
our $VERSION = '0.001';
our $AUTHORITY = 'cpan:GETTY';

# ABSTRACT: Create a network

use Moo;
use MooX::Cmd;
use MooX::Options protect_argv => 0, usage_string => 'USAGE: hcloud.pl network create --name <name> --ip-range <cidr>';

option name => (
    is       => 'ro',
    format   => 's',
    required => 1,
    doc      => 'Network name',
);

option 'ip_range' => (
    is       => 'ro',
    format   => 's',
    required => 1,
    long_doc => 'ip-range',
    doc      => 'IP range in CIDR notation (e.g. 10.0.0.0/8)',
);

sub execute {
    my ($self, $args, $chain) = @_;

    my $main = $chain->[0];
    my $cloud = $main->cloud;

    print "Creating network '", $self->name, "'...\n";
    my $network = $cloud->networks->create(
        name     => $self->name,
        ip_range => $self->ip_range,
    );
    print "Network created with ID ", $network->id, "\n";
}

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

WWW::Hetzner::CLI::Cmd::Network::Cmd::Create - Create a network

=head1 VERSION

version 0.001

=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan

=head1 SUPPORT

=head2 Source Code

The code is open to the world, and available for you to hack on. Please feel free to browse it and play
with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
from your repository :)

L<https://github.com/Getty/p5-www-hetzner>

  git clone https://github.com/Getty/p5-www-hetzner.git

=head1 AUTHOR

Torsten Raudssus <torsten@raudssus.de>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Torsten Raudssus.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> WWW-Hetzner-0.002.tar.gz: WWW-Hetzner-0.002/lib/WWW/Hetzner/CLI/Cmd/Network/Cmd/Create.pm <==
package WWW::Hetzner::CLI::Cmd::Network::Cmd::Create;
our $AUTHORITY = 'cpan:GETTY';
# ABSTRACT: Create a network

our $VERSION = '0.002';

use Moo;
use MooX::Cmd;
use MooX::Options protect_argv => 0, usage_string => 'USAGE: hcloud.pl network create --name <name> --ip-range <cidr>';

option name => (
    is       => 'ro',
    format   => 's',
    required => 1,
    doc      => 'Network name',
);

option 'ip_range' => (
    is       => 'ro',
    format   => 's',
    required => 1,
    long_doc => 'ip-range',
    doc      => 'IP range in CIDR notation (e.g. 10.0.0.0/8)',
);

sub execute {
    my ($self, $args, $chain) = @_;

    my $main = $chain->[0];
    my $cloud = $main->cloud;

    print "Creating network '", $self->name, "'...\n";
    my $network = $cloud->networks->create(
        name     => $self->name,
        ip_range => $self->ip_range,
    );
    print "Network created with ID ", $network->id, "\n";
}

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

WWW::Hetzner::CLI::Cmd::Network::Cmd::Create - Create a network

=head1 VERSION

version 0.002

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/Getty/p5-www-hetzner/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHOR

Torsten Raudssus <torsten@raudssus.de>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Torsten Raudssus.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
